..
    Copyright (c) 2015, 2016 Florian Wagner

    This file is part of GOparser.

    GOparser is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License, Version 3,
    as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

GOparser
========

|docs-latest| |docs-develop|

GOparser is a Python framework for working with gene ontology (GO) terms and
annotations.

If you use GOparser in your research, please cite `Wagner (PLoS One, 2015)`__.

__ go_pca_paper_

Installation
------------

.. code-block:: bash

    $ pip install goparser

Documentation
-------------

The `GOparser documentation <https://goparser.readthedocs.org/en/latest/>`_
is available on ReadTheDocs.

Copyright and License
---------------------

Copyright (c) 2015, 2016 Florian Wagner

::

  GOparser is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License, Version 3,
  as published by the Free Software Foundation.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.

.. _go_pca_paper: https://dx.doi.org/10.1371/journal.pone.0143196

.. |docs-latest| image:: https://readthedocs.org/projects/goparser/badge/?version=latest&hello
    :alt: Documentation Status (master branch)
    :scale: 100%
    :target: https://goparser.readthedocs.org/en/latest/?badge=latest&hello


.. |docs-develop| image:: https://readthedocs.org/projects/goparser/badge/?version=develop&hello
    :alt: Documentation Status (develop branch)
    :scale: 100%
    :target: https://goparser.readthedocs.org/en/develop/?badge=develop&hello